@@ -1,7 +1,9 @@
+from .priority_queue import PriorityQueue
 from .queue import Queue
 from .stack import Stack
 
 __all__ = [
     'Queue',
-    'Stack'
+    'Stack',
+    'PriorityQueue'
 ]
