@@ -11,12 +11,9 @@ from datastax.trees.binary_search_tree import BinarySearchTree, TreeNode
 class AVLNode(TreeNode):
     def __init__(self, data: Any,
                  left: AVLNode = None,
-                 right: AVLNode = None,
-                 height: int = 1):
+                 right: AVLNode = None):
         super().__init__(data, left, right)
-        self.left = left
-        self.right = right
-        self.height = height
+        self.height = 1
 
 
 class AVLTree(BinarySearchTree):
@@ -28,21 +25,25 @@ class AVLTree(BinarySearchTree):
     def _place(self, parent: Optional[AVLNode], data) -> Optional[AVLNode]:
         if not parent:
             return AVLNode(data)
-        elif parent.data < data:
+        if parent.data < data:
             parent.right = self._place(parent.right, data)
         elif data < parent.data:
             parent.left = self._place(parent.left, data)
         else:
             warnings.warn(
                 f"Insertion unsuccessful. Item '{data}' already exists "
-                "in BinarySearchTree", DuplicateNodeWarning)
-        parent.height = 1 + max(self.height(parent.left),
-                                self.height(parent.right))
+                "in AVLTree", DuplicateNodeWarning
+            )
+        parent.height = 1 + max(
+            self.height(parent.left),
+            self.height(parent.right)
+        )
         # Balancing the tree
-        return self.balance(parent, data)
+        return self._balance(parent)
 
     # Function to check balance factor of node
-    def balance_factor(self, parent: Optional[AVLNode]) -> int:
+    def balance_factor(self, parent: Optional[AVLNode] = None) -> int:
+        parent = parent or self.root
         if parent:
             return self.height(parent.left) - self.height(parent.right)
         return 0
@@ -53,14 +54,14 @@ class AVLTree(BinarySearchTree):
         return node.height if node else 0
 
     # Function to balance a node
-    def balance(self, parent: Optional[AVLNode],
-                data: Any) -> Optional[AVLNode]:
+    def _balance(self, parent: Optional[AVLNode]) -> Optional[AVLNode]:
         if not parent:
             return None
         balance_factor = self.balance_factor(parent)
         if balance_factor < -1:
             # Perform LL Rotation
-            if parent.right and parent.right.data < data:
+            # if parent.right and parent.right.data < data:
+            if parent.right and self.balance_factor(parent.right) <= 0:
                 return self._left_rotate(parent)
             # Perform RL Rotation
             else:
@@ -70,7 +71,8 @@ class AVLTree(BinarySearchTree):
 
         if balance_factor > 1:
             # Perform RR Rotation
-            if parent.left and data < parent.left.data:
+            # if parent.left and data < parent.left.data:
+            if parent.left and self.balance_factor(parent.left) >= 0:
                 return self._right_rotate(parent)
             # Perform LR Rotation
             else:
@@ -79,7 +81,7 @@ class AVLTree(BinarySearchTree):
                 return self._right_rotate(parent)
         return parent
 
-    # Private helper method of _place function to perform RR rotation
+    # Private helper method of balance function to perform RR rotation
     def _right_rotate(self, node: AVLNode) -> Optional[AVLNode]:
         left = node.left
         if left:
@@ -92,7 +94,7 @@ class AVLTree(BinarySearchTree):
                                   self.height(left.right))
         return left
 
-    # Private helper method of _place function to perform LL rotation
+    # Private helper method of balance function to perform LL rotation
     def _left_rotate(self, node: AVLNode) -> Optional[AVLNode]:
         right = node.right
         if right:
@@ -105,5 +107,11 @@ class AVLTree(BinarySearchTree):
                                    self.height(right.right))
         return right
 
-    def insert_path(self, data: Any, path: list[str] = None) -> None:
-        raise NotImplementedError
+    def _delete(self, root: Optional[AVLNode], item: Any) -> Optional[AVLNode]:
+        root = super()._delete(root, item)
+        if root:
+            root.height = 1 + max(
+                self.height(root.left),
+                self.height(root.right)
+            )
+        return self._balance(root)
