@@ -4,21 +4,23 @@ from __future__ import annotations
 import warnings
 from typing import Optional, Any
 
-from datastax.errors import DeletionFromEmptyTree
-from datastax.trees import BinaryTree, TreeNode
+from datastax.errors import DeletionFromEmptyTreeWarning
+from datastax.trees.private_trees.binary_tree import BinaryTree, TreeNode
 
 
-class HeapTreeNode(TreeNode):
-    def __init__(self, data: Any, left=None, right=None) -> None:
-        self.parent: Optional[HeapTreeNode] = None
-        self.prev_leaf: Optional[HeapTreeNode] = None
+class HeapNode(TreeNode):
+    def __init__(self, data: Any,
+                 left: HeapNode = None,
+                 right: HeapNode = None):
         super().__init__(data, left, right)
+        self.parent: Optional[HeapNode] = None
+        self.prev_leaf: Optional[HeapNode] = None
 
 
 class HeapTree(BinaryTree):
-    def __init__(self, array: list[Any] = None, root=None):
-        self._root: Optional[HeapTreeNode] = root
-        self._leaf: Optional[HeapTreeNode] = root
+    def __init__(self, array: list[Any] = None, root: HeapNode = None):
+        self._root: Optional[HeapNode] = root
+        self._leaf: Optional[HeapNode] = root
         super().__init__(array, root)
 
     def _construct(self, array: list[Any] = None) -> Optional[HeapTree]:
@@ -36,11 +38,11 @@ class HeapTree(BinaryTree):
         return self._leaf
 
     # Function to push an element inside a tree
-    def heappush(self, data: Any, root=None) -> None:
-        root = root or self.root
+    def heappush(self, data: Any) -> None:
+        root = self.root
         if data is None:
             return
-        node = HeapTreeNode(data)
+        node = HeapNode(data)
         if root is None:  # Heap Tree is Empty
             self._root = self._leaf = node
         # Heap tree has nodes. So inserting new node
@@ -59,14 +61,14 @@ class HeapTree(BinaryTree):
         self._heapify(node)
 
     # Private function to convert a subtree to heap
-    def _heapify(self, node: HeapTreeNode) -> None:
+    def _heapify(self, node: HeapNode) -> None:
         if node.parent and node.parent.data < node.data:
             node.parent.data, node.data = node.data, node.parent.data
             self._heapify(node.parent)
 
     # Private Helper method of heappush function to
     # update rightmost node in deepest level
-    def _update_leaf(self, node: HeapTreeNode) -> None:
+    def _update_leaf(self, node: HeapNode) -> None:
         # reach extreme left of next level if current level is full
         if node.parent is None:
             self._leaf = node
@@ -80,8 +82,10 @@ class HeapTree(BinaryTree):
     # Function to pop the largest element in the tree
     def heappop(self) -> Optional[Any]:
         if not self.root:
-            warnings.warn("Deletion Unsuccessful. Can't delete when"
-                          "tree is Already Empty", DeletionFromEmptyTree)
+            warnings.warn(
+                "Deletion Unsuccessful. Can't delete when"
+                "tree is Already Empty", DeletionFromEmptyTreeWarning
+            )
             return None
         deleted_data = self.root.data
         if self.root is self.leaf and not any(
@@ -103,7 +107,7 @@ class HeapTree(BinaryTree):
         return deleted_data
 
     # Private helper method of heappop function
-    def _shift_up(self, node: HeapTreeNode) -> None:
+    def _shift_up(self, node: HeapNode) -> None:
         root = node
         left_child = root.left
         right_child = root.right
@@ -116,5 +120,5 @@ class HeapTree(BinaryTree):
         root.data, node.data = node.data, root.data
         self._shift_up(root)
 
-    def insert_path(self, data: Any, path: list[str] = None) -> None:
-        raise NotImplementedError
+    def insert(self, item: Any):
+        self.heappush(item)
