@@ -1,18 +1,16 @@
 # Min Heap Tree Implementation
 from __future__ import annotations
 
-from typing import Any
-
-from datastax.trees.heap_tree import HeapTree, HeapTreeNode
+from datastax.trees.heap_tree import HeapTree, HeapNode
 
 
 class MinHeapTree(HeapTree):
-    def _heapify(self, node: HeapTreeNode) -> None:
+    def _heapify(self, node: HeapNode) -> None:
         if node.parent and node.parent.data > node.data:
             node.parent.data, node.data = node.data, node.parent.data
             self._heapify(node.parent)
 
-    def _shift_up(self, node: HeapTreeNode) -> None:
+    def _shift_up(self, node: HeapNode) -> None:
         root = node
         left_child = root.left
         right_child = root.right
@@ -24,6 +22,3 @@ class MinHeapTree(HeapTree):
             return
         root.data, node.data = node.data, root.data
         self._shift_up(root)
-
-    def insert_path(self, data: Any, path: list[str] = None) -> None:
-        raise NotImplementedError
